import { Form, Input, Button } from "antd";
import { motion } from "framer-motion";

export interface LoginFormData {
    username: string;
    password: string;
}

interface LoginFormProps {
    onSubmit: (data: LoginFormData) => void;
    isLoading: boolean;
}

export const LoginForm = ({ onSubmit, isLoading }: LoginFormProps) => {
    const [form] = Form.useForm<LoginFormData>();

    return (
        <motion.div
            initial={{ opacity: 0 }}
            animate={{ opacity: 1 }}
            exit={{ opacity: 0 }}
        >

            <Form
                form={form}
                layout="vertical"
                onFinish={onSubmit}
            >
                <Form.Item
                    label="用户名"
                    name="username"
                    rules={[
                        { required: true, message: "Username is required" },
                        { min: 2, message: "Username must be at least 2 characters" }
                    ]}
                >
                    <Input
                        placeholder="Username"
                        className="rounded-lg"
                    />
                </Form.Item>

                <Form.Item
                    label="密码"
                    name="password"
                    rules={[
                        { required: true, message: "Password is required" }
                    ]}
                >
                    <Input.Password
                        placeholder="Password"
                        className="rounded-lg"
                    />
                </Form.Item>

                <Form.Item>
                    <Button
                        type="primary"
                        htmlType="submit"
                        loading={isLoading}
                        className="w-full h-10 rounded-lg"
                    >
                        {isLoading ? "Signing in..." : "Sign In"}
                    </Button>
                </Form.Item>
            </Form>
        </motion.div>
    );
};
