import { StarIcon } from '@heroicons/react/24/outline';
import { Letter } from './types';
import { getBadgeStyle } from './utils';

interface LetterCardProps {
    letter: Letter;
}

export function LetterCard({ letter }: LetterCardProps) {
    return (
        <div className="group relative border-b    hover:bg-blue-100/30 p-6 transition-all duration-300 ease-in-out ">
            <div className="flex flex-col space-y-4">
                {/* Header Section */}
                <div className="flex justify-between items-center space-x-4">
                    <div className="flex items-center space-x-3">
                        <a
                            target="_blank"
                            href={`/letters/${letter.id}`}
                            className="text-xl font-semibold text-navy-900 group-hover:text-blue-700 transition-colors hover:underline"
                        >
                            {letter.title}
                        </a>

                    </div>
                </div>

                {/* Meta Information */}
                <div className="text-sm text-gray-600 flex items-center justify-between">
                    <span className="font-medium text-gray-800">{letter.sender} | {letter.unit}</span>
                    <span>{letter.date}</span>
                </div>

                {/* Badges Section */}
                <div className="flex flex-wrap gap-2 mt-2">
                    <Badge type="category" value={letter.category} />
                    <Badge type="status" value={letter.status} />
                    {letter.priority && <Badge type="priority" value={letter.priority} />}
                </div>

                {/* Content Preview */}
                {letter.content && (
                    <p className="text-sm text-gray-700 line-clamp-2 leading-relaxed mt-2">
                        {letter.content}
                    </p>
                )}
            </div>
        </div>
    );
}

function Badge({ type, value }: { type: 'priority' | 'category' | 'status'; value: string }) {
    return (
        <span
            className={`
                inline-flex items-center px-3 py-1 rounded-full text-xs font-semibold
                ${getBadgeStyle(type, value)}
                transition-all duration-150 ease-in-out transform hover:scale-105
            `}
        >
            {value.toUpperCase()}
        </span>
    );
}
