import { SearchOutlined } from '@ant-design/icons';
import { Form, Input, Select, Spin } from 'antd';
import { useEffect } from 'react';

interface SearchFiltersProps {
    searchTerm: string;
    onSearchChange: (value: string) => void;
    filterCategory: string;
    onCategoryChange: (value: string) => void;
    filterStatus: string;
    onStatusChange: (value: string) => void;
    className?: string;
    isLoading?: boolean;
}

const LoadingIndicator = () => (
    <Spin size="small" className="ml-2" />
);

export function SearchFilters({
    searchTerm,
    onSearchChange,
    filterCategory,
    onCategoryChange,
    filterStatus,
    onStatusChange,
    className,
    isLoading = false
}: SearchFiltersProps) {
    const [form] = Form.useForm();

    // 统一处理表单初始值
    const initialValues = {
        search: searchTerm,
        category: filterCategory,
        status: filterStatus
    };

    useEffect(() => {
        form.setFieldsValue(initialValues);
    }, [searchTerm, filterCategory, filterStatus, form]);

    return (
        <Form
            form={form}
            layout="vertical"
            className={className}
            initialValues={initialValues}
        >
            <div className="grid grid-cols-1 md:grid-cols-3 gap-4">
                <Form.Item name="search" noStyle>
                    <Input
                        prefix={<SearchOutlined />}
                        placeholder="搜索关键词、发件人或单位..."
                        onChange={(e) => onSearchChange(e.target.value)}
                        allowClear
                        suffix={isLoading ? <LoadingIndicator /> : null}
                    />
                </Form.Item>

                <Form.Item name="category" noStyle>
                    <Select
                        className="w-full"
                        onChange={onCategoryChange}
                        options={[
                            { value: 'all', label: '所有分类' },
                            { value: 'complaint', label: '投诉' },
                            { value: 'suggestion', label: '建议' },
                            { value: 'request', label: '请求' },
                            { value: 'feedback', label: '反馈' }
                        ]}
                    />
                </Form.Item>

                <Form.Item name="status" noStyle>
                    <Select
                        className="w-full"
                        onChange={onStatusChange}
                        options={[
                            { value: 'all', label: '所有状态' },
                            { value: 'pending', label: '待处理' },
                            { value: 'in-progress', label: '处理中' },
                            { value: 'resolved', label: '已解决' }
                        ]}
                    />
                </Form.Item>
            </div>
        </Form>
    );
}
