import { useState, useMemo } from 'react';
import { Letter } from './types';

export function useLetterFilters(letters: Letter[]) {
    const [currentPage, setCurrentPage] = useState(1);
    const [searchTerm, setSearchTerm] = useState('');
    const [filterStatus, setFilterStatus] = useState<string>('all');
    const [filterCategory, setFilterCategory] = useState<string>('all');

    const filteredLetters = useMemo(() => {
        return letters.filter(letter => {
            const matchesSearch = [letter.title, letter.sender, letter.unit]
                .some(field => field.toLowerCase().includes(searchTerm.toLowerCase()));

            const matchesCategory = filterCategory === 'all' || letter.category === filterCategory;
            const matchesStatus = filterStatus === 'all' || letter.status === filterStatus;

            return matchesSearch && matchesCategory && matchesStatus;
        });
    }, [letters, searchTerm, filterCategory, filterStatus]);

    return {
        currentPage,
        setCurrentPage,
        searchTerm,
        setSearchTerm,
        filterStatus,
        setFilterStatus,
        filterCategory,
        setFilterCategory,
        filteredLetters,
    };
}
