import { FunnelIcon, MagnifyingGlassIcon } from "@heroicons/react/24/outline";
import { leaders } from "./mock";
import { useMemo, useState } from "react";
import { Leader } from "./types";

export default function Filter() {
    const [selectedLeader, setSelectedLeader] = useState<Leader | null>(null);
    const [searchQuery, setSearchQuery] = useState('');
    const [selectedDivision, setSelectedDivision] = useState<string>('all');

    const divisions = useMemo(() => {
        return ['all', ...new Set(leaders.map(leader => leader.division))];
    }, []);

    return <div className="flex flex-col md:flex-row gap-4 mb-8">
        <div className="relative flex-1">
            <MagnifyingGlassIcon className="absolute left-3 top-1/2 transform -translate-y-1/2 text-tertiary-300 w-5 h-5" />
            <input
                type="text"
                placeholder="Search by name or rank..."
                className="w-full pl-10 pr-4 py-3 rounded-lg border border-gray-200 focus:ring-2 focus:ring-[#00308F] focus:border-transparent"
                value={searchQuery}
                onChange={(e) => setSearchQuery(e.target.value)}
            />
        </div>
        <div className="relative">
            <FunnelIcon className="absolute left-3 top-1/2 transform -translate-y-1/2 text-tertiary-300 w-5 h-5" />
            <select
                className="pl-10 pr-8 py-3 rounded-lg border border-gray-200 focus:ring-2 focus:ring-[#00308F] appearance-none bg-white"
                value={selectedDivision}
                onChange={(e) => setSelectedDivision(e.target.value)}
            >
                {divisions.map(division => (
                    <option key={division} value={division}>
                        {division === 'all' ? 'All Divisions' : division}
                    </option>
                ))}
            </select>
        </div>
    </div>
}