import React from "react";
import { Button } from "./Button";

type LeaderCardProps = {
    name: string;
    title: string;
    description: string;
    imageUrl: string;

    onClick?: () => void;  // 添加整个卡片的点击事件
};

const LeaderCard: React.FC<LeaderCardProps> = ({
    name,
    title,
    description,
    imageUrl,
    onClick,
}) => {
    return (
        <div
            className="group flex bg-white rounded-2xl shadow-md hover:shadow-2xl transition-all duration-300 ease-out max-w-2xl border border-gray-100 hover:border-blue-100 cursor-pointer overflow-hidden"
            onClick={onClick}
            role="button"
            tabIndex={0}
            onKeyDown={(e) => {
                if (e.key === 'Enter' || e.key === ' ') {
                    onClick?.();
                }
            }}
        >
            {/* Image Section */}
            <div className="relative flex-shrink-0 overflow-hidden">
                <img
                    src={imageUrl}
                    alt={name}
                    className="w-44 h-64 object-cover transition-transform duration-500 group-hover:scale-105"
                    style={{
                        aspectRatio: "3/4",
                    }}
                />
                <div className="absolute inset-0 bg-gradient-to-t from-black/20 to-transparent opacity-0 group-hover:opacity-100 transition-opacity duration-300" />
            </div>

            {/* Content Section */}
            <div className="flex flex-col justify-between p-5 flex-1">
                <div className="space-y-3">
                    {/* Name and Title */}
                    <div className="transform transition-transform duration-300 group-hover:translate-x-2">
                        <h3 className="text-2xl font-semibold text-gray-800 mb-1 tracking-tight group-hover:text-primary-600 transition-colors">
                            {name}
                        </h3>
                        <p className="text-base font-medium text-primary-600 tracking-wide group-hover:text-blue-500">
                            {title}
                        </p>
                    </div>

                    {/* Description */}
                    <p className="text-gray-600  text-base leading-relaxed line-clamp-4 font-light group-hover:text-gray-700">
                        {description}
                    </p>
                </div>

                {/* Decorative Element */}
                <div className="mt-4">
                    <div className="h-0.5 w-8 bg-blue-600 rounded-full transform origin-left transition-all duration-300 group-hover:w-16 group-hover:bg-gradient-to-r from-blue-600 to-blue-400" />
                </div>
            </div>
        </div>
    );
};


export default LeaderCard;
