import { useLocation, useParams } from "react-router-dom";
import { motion } from "framer-motion";
import { PaperAirplaneIcon } from "@heroicons/react/24/outline";
import { LetterFormProvider } from "../context/LetterEditorContext";
import { LetterBasicForm } from "../form/LetterBasicForm";

export default function LetterEditorLayout() {
	const location = useLocation();
	const params = new URLSearchParams(location.search);

	const receiverId = params.get("receiverId");
	const termId = params.get("termId");

	return (
		<motion.div
			className="min-h-screen rounded-xl overflow-hidden border border-gray-200 shadow-lg" // 添加圆角和溢出隐藏
			initial={{ opacity: 0 }}
			animate={{ opacity: 1 }}
			transition={{ duration: 0.8 }}>
			<div className="bg-gradient-to-r from-[#00308F] to-[#0353A4] text-white py-8">
				<div className="w-full px-4 max-w-7xl mx-auto">
					<motion.div
						className="flex items-center justify-center mb-6"
						initial={{ scale: 0 }}
						animate={{ scale: 1 }}
						transition={{
							delay: 0.2,
							type: "spring",
							stiffness: 100,
						}}>
						<PaperAirplaneIcon className="h-12 w-12" />
						<h1 className="text-3xl font-bold ml-4">撰写信件</h1>
					</motion.div>

					{/* 隐私保护说明 */}
					<div className="flex flex-wrap gap-6 text-sm justify-center mb-4">
						<div className="flex items-center gap-2">
							<svg
								className="w-5 h-5"
								fill="none"
								stroke="currentColor"
								viewBox="0 0 24 24">
								<path
									strokeLinecap="round"
									strokeLinejoin="round"
									strokeWidth="2"
									d="M16 7a4 4 0 11-8 0 4 4 0 018 0zM12 14a7 7 0 00-7 7h14a7 7 0 00-7-7z"
								/>
							</svg>
							<span>个人信息严格保密</span>
						</div>
						<div className="flex items-center gap-2">
							<svg
								className="w-5 h-5"
								fill="none"
								stroke="currentColor"
								viewBox="0 0 24 24">
								<path
									strokeLinecap="round"
									strokeLinejoin="round"
									strokeWidth="2"
									d="M9 12h6m-6 4h6m2 5H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z"
								/>
							</svg>
							<span>支持匿名反映问题</span>
						</div>
						<div className="flex items-center gap-2">
							<svg
								className="w-5 h-5"
								fill="none"
								stroke="currentColor"
								viewBox="0 0 24 24">
								<path
									strokeLinecap="round"
									strokeLinejoin="round"
									strokeWidth="2"
									d="M8 11V7a4 4 0 118 0m-4 8v2m-6 4h12a2 2 0 002-2v-6a2 2 0 00-2-2H6a2 2 0 00-2 2v6a2 2 0 002 2z"
								/>
							</svg>
							<span>网络数据加密存储</span>
						</div>
					</div>

					{/* 隐私承诺 */}
					<div className="text-sm text-blue-100 border-t border-blue-400/30 pt-4 max-w-4xl mx-auto text-center">
						<p>
							我们承诺：您的个人信息将被严格保密，不向任何第三方透露。您可以选择匿名反映问题，平台会自动过滤可能暴露身份的信息。
						</p>
					</div>
				</div>
			</div>

			<div className="w-full px-2 py-2">
				<LetterFormProvider receiverId={receiverId} termId={termId}>
					<LetterBasicForm />
				</LetterFormProvider>
			</div>
		</motion.div>
	);
}
