export class PostParams {
	private static instance: PostParams; // 静态私有变量，用于存储单例实例
	private postParams: Array<object>; // 私有数组属性，用于存储对象

	private constructor() {
		this.postParams = []; // 初始化空数组
	}

	public static getInstance(): PostParams {
		if (!PostParams.instance) {
			PostParams.instance = new PostParams();
		}
		return PostParams.instance;
	}

	public addItem(item: object): void {
		// 使用更可靠的方式比较查询参数
		const isDuplicate = this.postParams.some((existingItem: any) => {
			if (item && existingItem) {
				const itemWhere = (item as any).where;
				const existingWhere = existingItem.where;
				return (
					itemWhere?.parentId === existingWhere?.parentId &&
					itemWhere?.type === existingWhere?.type
				);
			}
			return false;
		});

		if (!isDuplicate) {
			this.postParams.push(item);
		}
	}

	public removeItem(item: object): void {
		// 使用相同的比较逻辑移除项
		this.postParams = this.postParams.filter((existingItem: any) => {
			if (item && existingItem) {
				const itemWhere = (item as any).where;
				const existingWhere = existingItem.where;
				return !(
					itemWhere?.parentId === existingWhere?.parentId &&
					itemWhere?.type === existingWhere?.type
				);
			}
			return true;
		});
	}

	public getItems(): Array<object> {
		return [...this.postParams];
	}
}
